@@ -1,6 +1,7 @@
 from functools import partial
 import inspect
 from typing import Callable
+from urllib import request
 from graphene import Field, List
 import graphene
 from graphene.types.utils import get_type
@@ -81,7 +82,7 @@ class BalderFilteredWithOffset(Field):
         # TODO: here it would be good to filter for permissions if it is ndeeded
         filter_kwargs = {k: v for k, v in kwargs.items() if k in filtering_args}
         qs = getattr(root, related_field)
-        qs = filterset_class(data=filter_kwargs, queryset=qs).qs
+        qs = filterset_class(data=filter_kwargs, queryset=qs, request=info.context).qs
         offset = kwargs.get("offset", 0)
         limit = kwargs.get("limit", None)
         return qs[offset : (offset + limit) if limit else None]
@@ -93,7 +94,9 @@ class BalderFilteredWithOffset(Field):
         # TODO: here it would be good to filter for permissions if it is ndeeded
         filter_kwargs = {k: v for k, v in kwargs.items() if k in filtering_args}
         qs = filterset_class(
-            data=filter_kwargs, queryset=queryset_resolver(root, info, *args, **kwargs)
+            data=filter_kwargs,
+            queryset=queryset_resolver(root, info, *args, **kwargs),
+            request=info.context,
         ).qs
         offset = kwargs.get("offset", 0)
         limit = kwargs.get("limit", None)
